@@ -43,9 +43,9 @@ use warnings;
 use strict;
 
 use Carp qw(croak);
-use Params::Classify qw(is_ref);
+use Params::Classify 0.000 qw(is_ref);
 
-our $VERSION = "0.006";
+our $VERSION = "0.007";
 
 use parent "Exporter";
 our @EXPORT_OK = qw(entropy_source with_entropy_source);
@@ -130,7 +130,8 @@ Andrew Main (Zefram) <zefram@fysh.org>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2006, 2007, 2009 Andrew Main (Zefram) <zefram@fysh.org>
+Copyright (C) 2006, 2007, 2009, 2011
+Andrew Main (Zefram) <zefram@fysh.org>
 
 =head1 LICENSE
 
